function [Tvf, dh] = parcel_move(T, p, r, e, Tc, pc, wt, dh_to_sat, pf, thermo_type)
 
% move parcel to pressure pf
% see moist_ape_thermo for variable definitions
  
 error(nargchk(10, 10, nargin))     

 switch lower(thermo_type)
  case 'full'
   cpw            = PARS('cp_v'); % specific heat capacity of water vapor
  case 'simple'
   % idealized GCM thermo is equivalent to having the same heat capacity
   % for water vapor and dry air
   cpw            = PARS('cp');
  otherwise
   error(['Unknown type, ', thermo_type, 'of thermodynamic formulation.'])
 end

 R              = PARS('gas_constant');
 Rw             = PARS('gas_constant_v');
 cp             = PARS('cp');
 eps            = R/Rw;


 unsat = pf>pc;
 sat   = pf<=pc;


 % if don't reach saturation
 kappa     = (R+wt.*Rw)./(cp+wt.*cpw);
 Tf_unsat  = T.*(pf./p).^kappa;
 w         = eps*e./(p-e);
 Tvf_unsat = (1+w./eps).*Tf_unsat./(1+wt);
 dh_unsat  = (cp+wt.*cpw).*(Tf_unsat-T)./(1+wt); % equation 12 Lorenz

 if all(r==0)
  % dry mape
  Tvf = Tvf_unsat;
  dh = dh_unsat;
  return
 end


 % if reach saturation
 s_sat_0 = moist_ape_sat_entropy(Tc, pc, wt, thermo_type);

 % iterate
 Tf_sat = Tc; % initial guess
 dT     = ones(size(T));
 T_perturb = 0.1; % used to evaluated ds_dT
 while any(abs(dT(sat))>0.01)
  s_sat = moist_ape_sat_entropy(Tf_sat, pf, wt, thermo_type);

  Tf_sat_perturb     = Tf_sat+T_perturb;
  s_sat_perturb = moist_ape_sat_entropy(Tf_sat_perturb, pf, wt, thermo_type);

  ds_sat_dT       = (s_sat_perturb-s_sat)/T_perturb;
  dT              = (s_sat_0-s_sat)./ds_sat_dT;
  Tf_sat          = Tf_sat+ dT;
 end

 [es_at_Tf, L_at_Tf] = moist_ape_es(Tf_sat, thermo_type);
 w_at_Tf             = eps*es_at_Tf./(pf-es_at_Tf);
 Tvf_sat             = (1+w_at_Tf./eps).*Tf_sat./(1+wt);

 [es_at_Tc, L_at_Tc] = moist_ape_es(Tc, thermo_type);
 w_at_Tc         = eps*es_at_Tc./(pc-es_at_Tc);

 % based on equation 16 (doesn't require a c)
 dh_sat = ((cp+wt*cpw).*(Tf_sat-Tc)-...
           (wt.*(L_at_Tf-L_at_Tc)-...
            w_at_Tf.*L_at_Tf+w_at_Tc.*L_at_Tc))./(1+wt)+...
          dh_to_sat;


 % combine cases
 dh   =  dh_unsat.*unsat + dh_sat.*sat;
 Tf   =  Tf_unsat.*unsat + Tf_sat.*sat;
 Tvf  =  Tvf_unsat.*unsat + Tvf_sat.*sat;


